Node

Struct Node 

pub struct Node {
    pub host_id: Uuid,
    pub address: NodeAddr,
    pub datacenter: Option<String>,
    pub rack: Option<String>,
    /* private fields */
}
Node represents a cluster node along with its data and connections

Note: if a Node changes its broadcast address, then it is not longer represented by the same instance of Node struct, but instead a new instance is created (for implementation reasons).

Fields

host_id: Uuid

Unique identifier of the node.

address: NodeAddr

Address of the node, which is used to connect to it. This address is either the one broadcast by the node itself (NodeAddr::Translatable) or the one used to connect to it in the first place if it’s a contact point (NodeAddr::Untranslatable).

datacenter: Option<String>

Datacenter of the node, if known.

rack: Option<String>

Rack of the node, if known.

Implementations

Source

impl Node

pub fn sharder(&self) -> Option<Sharder>

Retrieves the sharder for this node, if it has one.

If the node is disabled (i.e., it has no connection pool), or the node is not sharded (i.e., it’s not a ScyllaDB node), this will return None.

If the node is enabled and does not have a sharder, this means it’s not a ScyllaDB node.

pub fn is_connected(&self) -> bool

Returns true if the driver has any open connections in the pool for this node.

pub fn is_enabled(&self) -> bool

Returns a boolean which indicates whether this node was is enabled. Only enabled nodes will have connections open. For disabled nodes, no connections will be opened.