#[non_exhaustive]pub enum SchemaAgreementError {
ConnectionPoolError(ConnectionPoolError),
PrepareError(PrepareError),
RequestError(RequestAttemptError),
TracesEventsIntoRowsResultError(IntoRowsResultError),
SingleRowError(SingleRowError),
Timeout(Duration),
RequiredHostAbsent(Uuid),
}Expand description
An error that occurred when awating schema agreement.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ConnectionPoolError(ConnectionPoolError)
Failed to find a node with working connection pool.
PrepareError(PrepareError)
Failed to prepare the schema version query.
RequestError(RequestAttemptError)
Failed to execute schema version query on one of the connections.
The driver attempts to fetch schema version on all connections in the pool (for all nodes). It expects all of the requests to succeed. If at least one request fails, schema version fetch is considered failed. This variant contains an error from one of the failing request attempts.
TracesEventsIntoRowsResultError(IntoRowsResultError)
Failed to convert schema version query result into rows result.
This variant should be named SchemaVersionIntoRowsResultError, current name
is a copy-paste error. It will be renamed in 2.0
SingleRowError(SingleRowError)
Failed to deserialize a single row from schema version query response.
Timeout(Duration)
Schema agreement timed out.
RequiredHostAbsent(Uuid)
Some host mandatory for schema agreement is not present in the connection pool.