pub enum MaybeEmpty<T>where
T: Emptiable,{
Empty,
Value(T),
}Expand description
A value that may be empty or not.
MaybeEmpty was introduced to help support the quirk described in Emptiable
for Rust types which can’t represent the empty, additional value.
This type can be both serialized and deserialized. When serializing,
MaybeEmpty::Empty will produce an empty value (0 bytes) for emptiable types.
When deserializing, an empty value will be represented as MaybeEmpty::Empty.
Variants
Empty
Represents an empty value (0 bytes in the serialized form).
Value(T)
Represents a non-empty value.